'# MWS Version: Version 2006.0.0 - Oct 27 2005 - 15:07:04

'# length = mm
'# frequency = GHz
'# time = ns
'# frequency range: fmin = 31.5 fmax = 38.5


'@ use template: Antenna (on Planar Substrate)

' Template for Antenna on Planar Substrate
' ========================================

' (CSTxMWSxONLY)

' draw the bounding box

Plot.DrawBox True

' set units to mm, ghz

With Units 
     .Geometry "mm" 
     .Frequency "ghz" 
     .Time "ns" 
End With 

' set background material to vacuum

With Background 
     .Type "Normal" 
     .Epsilon "1.0" 
     .Mue "1.0" 
     .XminSpace "0.0" 
     .XmaxSpace "0.0" 
     .YminSpace "0.0" 
     .YmaxSpace "0.0" 
     .ZminSpace "0.0" 
     .ZmaxSpace "0.0" 
End With 

' set boundary conditions to open, zmin to electric

With Boundary
     .Xmin "open" 
     .Xmax "open" 
     .Ymin "open" 
     .Ymax "open" 
     .Zmin "electric" 
     .Zmax "expanded open" 
     .Xsymmetry "none" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
End With

' optimize mesh settings for planar structures

With Mesh 
     .MergeThinPECLayerFixpoints "True" 
     .RatioLimit "50" 
     .AutomeshRefineAtPecLines "True", "4"
End With 

' change mesh adaption scheme to energy 
' 		(planar structures tend to store high energy 
'     	 locally at edges rather than globally in volume)

MeshAdaption3D.SetAdaptionStrategy "Energy" 

'@ new component: component1

Component.New "component1" 


'@ define brick: component1:solid1

With Brick
     .Reset 
     .Name "solid1" 
     .Component "component1" 
     .Material "PEC" 
     .Xrange "-2", "2" 
     .Yrange "-2", "2" 
     .Zrange "-0.02", "0" 
     .Create
End With


'@ define material: material1

With Material 
     .Reset 
     .Name "material1"
     .FrqType "hf" 
     .Type "Normal" 
     .Epsilon "2.2" 
     .Mue "1.0" 
     .Kappa "0.0" 
     .TanD "0.0" 
     .TanDFreq "0.0" 
     .TanDGiven "False" 
     .TanDModel "ConstTanD" 
     .KappaM "0.0" 
     .TanDM "0.0" 
     .TanDMFreq "0.0" 
     .TanDMGiven "False" 
     .TanDMModel "ConstTanD" 
     .DispModelEps "None" 
     .DispModelMue "None" 
     .DispersiveFittingSchemeEps "General 1st" 
     .DispersiveFittingSchemeMue "General 1st" 
     .UseGeneralDispersionEps "False" 
     .UseGeneralDispersionMue "False" 
     .Rho "0.0" 
     .ThermalConductivity "0.0" 
     .SetActiveMaterial "hf" 
     .Colour "0", "1", "1" 
     .Wireframe "False" 
     .Transparency "0" 
     .Create
End With 


'@ define brick: component1:solid2

With Brick
     .Reset 
     .Name "solid2" 
     .Component "component1" 
     .Material "material1" 
     .Xrange "-2", "2" 
     .Yrange "-2", "2" 
     .Zrange "0", "0.254" 
     .Create
End With


'@ activate local coordinates

WCS.ActivateWCS "local"


'@ move wcs

WCS.MoveWCS "local", "0.0", "0.0", "0.254" 


'@ define extrude: component1:solid3

With Extrude 
     .Reset 
     .Name "solid3" 
     .Component "component1" 
     .Material "PEC" 
     .Mode "Pointlist" 
     .Height "0.02" 
     .Twist "0.0" 
     .Taper "0.0" 
     .Origin "0.0", "0.0", "0.0" 
     .Uvector "1.0", "0.0", "0.0" 
     .Vvector "0.0", "1.0", "0.0" 
     .Point "-1.5", "1.35" 
     .LineTo "-1.5", "-1.35" 
     .LineTo "-1.5", "-1.35" 
     .LineTo "-1.125", "-1.35" 
     .LineTo "-1.125", "0" 
     .LineTo "-0.125", "0" 
     .LineTo "-0.125", "-2" 
     .LineTo "0.125", "-2" 
     .LineTo "0.125", "0" 
     .LineTo "1.125", "0" 
     .LineTo "1.125", "-1.35" 
     .LineTo "1.5", "-1.35" 
     .LineTo "1.5", "1.35" 
     .LineTo "-1.5", "1.35" 
     .Create 
End With 


'@ define frequency range

Solver.FrequencyRange "31.5", "38.5" 


'@ define boundaries

With Boundary
     .Xmin "expanded open" 
     .Xmax "expanded open" 
     .Ymin "expanded open" 
     .Ymax "expanded open" 
     .Zmin "electric" 
     .Zmax "expanded open" 
     .Xsymmetry "none" 
     .Ysymmetry "none" 
     .Zsymmetry "none" 
     .ZminTemperature "" 
     .ZminTemperatureType "None" 
End With


'@ define port: 1

With Port 
     .Reset 
     .PortNumber "1" 
     .NumberOfModes "1" 
     .AdjustPolarization False 
     .PolarizationAngle "0.0" 
     .ReferencePlaneDistance "0" 
     .TextSize "50" 
     .Coordinates "Free" 
     .Orientation "ymin" 
     .PortOnBound "False" 
     .ClipPickedPortToBound "False" 
     .Xrange "-1.35", "1.35" 
     .Yrange "-2", "-2" 
     .Zrange "-0.02", "0.772" 
     .XrangeAdd "0.0", "0.0" 
     .YrangeAdd "0.0", "0.0" 
     .ZrangeAdd "0.0", "0.0" 
     .Create 
End With 


'@ define farfield monitor: farfield (f=35)

With Monitor 
     .Reset 
     .Name "farfield (f=35)" 
     .Domain "Frequency" 
     .FieldType "Farfield" 
     .Frequency "35" 
     .Create 
End With 


'@ define solver parameters

With Solver 
     .CalculationType "TD-S" 
     .StimulationPort "All" 
     .StimulationMode "All" 
     .SteadyStateLimit "-30" 
     .MeshAdaption "False" 
     .AutoNormImpedance "False" 
     .NormingImpedance "50" 
     .CalculateModesOnly "False" 
     .SParaSymmetry "False" 
     .StoreTDResultsInCache "False" 
     .FullDeembedding "False" 
     .UseNetworkComputing "False" 
End With 


'@ define discrete port: 2

With DiscretePort 
     .Reset 
     .PortNumber "2" 
     .Type "SParameter" 
     .Impedance "50.0" 
     .Voltage "1.0" 
     .Current "1.0" 
     .Point1 "0.0", "-2", "0.01" 
     .Point2 "0.0", "-2", "-0.255" 
     .UsePickedPoints "False" 
     .LocalCoordinates "True" 
     .Monitor "False" 
     .Create 
End With 


'@ define solver parameters

With Solver 
     .CalculationType "TD-S" 
     .StimulationPort "All" 
     .StimulationMode "All" 
     .SteadyStateLimit "-30" 
     .MeshAdaption "False" 
     .AutoNormImpedance "False" 
     .NormingImpedance "50" 
     .CalculateModesOnly "False" 
     .SParaSymmetry "False" 
     .StoreTDResultsInCache "False" 
     .FullDeembedding "False" 
     .UseNetworkComputing "False" 
End With 


'@ delete port: port2

Port.Delete "2" 


'@ define solver parameters

With Solver 
     .CalculationType "TD-S" 
     .StimulationPort "All" 
     .StimulationMode "All" 
     .SteadyStateLimit "-30" 
     .MeshAdaption "False" 
     .AutoNormImpedance "False" 
     .NormingImpedance "50" 
     .CalculateModesOnly "False" 
     .SParaSymmetry "False" 
     .StoreTDResultsInCache "False" 
     .FullDeembedding "False" 
     .UseNetworkComputing "False" 
End With 


